@@ -1,11 +1,7 @@
-import logging
-
 from django.core.management.base import BaseCommand
 
 from django_pgviews.models import ViewRefresher
 
-log = logging.getLogger("django_pgviews.refresh_pgviews")
-
 
 class Command(BaseCommand):
     help = """Refresh materialized Postgres views for all installed apps."""
